@@ -31,5 +31,5 @@ class MinerDoesNotExist(Exception):
     pass
 
 
-class InvalidMinerAddress(Exception):
+class InvalidCoin(Exception):
     pass
