@@ -20,14 +20,35 @@
 
 import si_prefix
 
+from . import poolapi
+from . import exceptions
 
-def format_hashrate(hashrate: int):
-    return si_prefix.si_format(hashrate) + "H/s"
+coins = {}
 
 
-def format_weis(weis: int, prec=5):
-    amount = round(weis / 10**18, prec)
-    if amount == int(amount):
-        # Get rid of .0
-        amount = int(amount)
-    return str(amount) + " ETH"
+def update_coins():
+    global coins
+    for coin in poolapi.coins():
+        coins[coin.ticker] = {
+            "hashrate_unit": coin.hashrate_unit,
+            "decimal_places": coin.decimal_places,
+        }
+
+
+def format_hashrate(hashrate: int, coin: str):
+    coin = coin.lower()
+    try:
+        return si_prefix.si_format(hashrate) + coins[coin]["hashrate_unit"]
+    except KeyError:
+        raise (exceptions.InvalidCoin(f"Coin {coin.upper()} is invalid!"))
+
+
+def format_decimals(value: int, coin: str, prec=6):
+    coin = coin.lower()
+    try:
+        amount = round(value / 10 ** coins[coin]["decimal_places"], prec)
+        if amount == int(amount):
+            amount = int(amount)
+        return f"{amount} {coin.upper()}"
+    except KeyError:
+        raise (exceptions.InvalidCoin(f"Coin {coin.upper()} is invalid!"))
